@@ -13,6 +13,12 @@ rows_truncate <- function(x, ..., in_place = FALSE) {
   UseMethod("rows_truncate", x)
 }
 
+#' @export
+rows_truncate.data.frame <- function(x, ..., in_place = NULL) {
+  stopifnot(is.null(in_place) || !in_place)
+  x[0, ]
+}
+
 #' @export
 rows_truncate.tbl_sql <- function(x, ...,
                                   in_place = NULL) {
