@@ -27,7 +27,8 @@ test_that("schema handling on MSSQL and Postgres works", {
   expect_message(sql_schema_create(con_db, "1-dm_schema_TEST"), "created")
   expect_dm_error(sql_schema_create(con_db, "1-dm_schema_TEST"), "schema_exists")
   expect_identical(
-    sql_schema_list(con_db, include_default = FALSE) %>%
+    con_db %>%
+      sql_schema_list(include_default = FALSE) %>%
       filter(schema_name == "1-dm_schema_TEST") %>%
       pull(schema_name),
     "1-dm_schema_TEST"
